@@ -12,6 +12,8 @@ from ics.alarm import DisplayAlarm
 from oauthlib.oauth2 import TokenExpiredError
 from quart import Quart, redirect, render_template, request, session, url_for
 from requests_oauthlib import OAuth2Session  # type: ignore
+import sentry_sdk
+from sentry_sdk.integrations.quart import QuartIntegration
 from uvicorn.middleware.proxy_headers import ProxyHeadersMiddleware  # type: ignore
 
 
@@ -31,6 +33,10 @@ QUART_DEBUG = getenv("QUART_DEBUG", False)
 if QUART_DEBUG:
     logging.basicConfig(level=logging.DEBUG)
 
+SENTRY_DSN = getenv("SENTRY_DSN")
+if SENTRY_DSN:
+    sentry_sdk.init(SENTRY_DSN, integrations=[QuartIntegration()])
+
 API_BASE_URL = getenv("API_BASE_URL", "https://discordapp.com/api")
 AUTHORIZATION_BASE_URL = f"{API_BASE_URL}/oauth2/authorize"
 TOKEN_URL = f"{API_BASE_URL}/oauth2/token"
